@@ -14,8 +14,8 @@
 import socket
 
 import botocore.config
+from tests import mock
 from tests import unittest
-import mock
 
 from botocore import args
 from botocore import exceptions
@@ -91,6 +91,7 @@ class TestCreateClientArgs(unittest.TestCase):
             'verify': True,
             'max_pool_connections': 10,
             'proxies': None,
+            'proxies_config': None,
             'socket_options': self.default_socket_options,
             'client_cert': None,
         }
@@ -100,87 +101,35 @@ class TestCreateClientArgs(unittest.TestCase):
         )
 
     def test_compute_s3_configuration(self):
-        scoped_config = {}
-        client_config = None
-        self.assertIsNone(
-            self.args_create.compute_s3_config(
-                scoped_config, client_config))
+        self.assertIsNone(self.args_create.compute_s3_config(None))
 
-    def test_compute_s3_config_only_scoped_config(self):
-        scoped_config = {
-            's3': {'use_accelerate_endpoint': True},
-        }
-        client_config = None
+    def test_compute_s3_config_only_config_store(self):
+        self.config_store.set_config_variable(
+            's3', {'use_accelerate_endpoint': True})
         self.assertEqual(
-            self.args_create.compute_s3_config(scoped_config, client_config),
-            {'use_accelerate_endpoint': True}
-        )
-
-    def test_client_s3_accelerate_from_varying_forms_of_true(self):
-        scoped_config= {'s3': {'use_accelerate_endpoint': 'True'}}
-        client_config = None
-
-        self.assertEqual(
-            self.args_create.compute_s3_config(
-                {'s3': {'use_accelerate_endpoint': 'True'}},
-                client_config=None),
-            {'use_accelerate_endpoint': True}
-        )
-        self.assertEqual(
-            self.args_create.compute_s3_config(
-                {'s3': {'use_accelerate_endpoint': 'true'}},
-                client_config=None),
-            {'use_accelerate_endpoint': True}
-        )
-        self.assertEqual(
-            self.args_create.compute_s3_config(
-                {'s3': {'use_accelerate_endpoint': True}},
-                client_config=None),
+            self.args_create.compute_s3_config(None),
             {'use_accelerate_endpoint': True}
         )
 
     def test_client_s3_accelerate_from_client_config(self):
         self.assertEqual(
             self.args_create.compute_s3_config(
-                scoped_config=None,
                 client_config=Config(s3={'use_accelerate_endpoint': True})
             ),
             {'use_accelerate_endpoint': True}
         )
 
-    def test_client_s3_accelerate_client_config_overrides_scoped(self):
+    def test_client_s3_accelerate_client_config_overrides_config_store(self):
+        self.config_store.set_config_variable(
+            's3', {'use_accelerate_endpoint': False})
         self.assertEqual(
             self.args_create.compute_s3_config(
-                scoped_config={'s3': {'use_accelerate_endpoint': False}},
                 client_config=Config(s3={'use_accelerate_endpoint': True})
             ),
             # client_config beats scoped_config
             {'use_accelerate_endpoint': True}
         )
 
-    def test_client_s3_dualstack_handles_varying_forms_of_true(self):
-        scoped_config= {'s3': {'use_dualstack_endpoint': 'True'}}
-        client_config = None
-
-        self.assertEqual(
-            self.args_create.compute_s3_config(
-                {'s3': {'use_dualstack_endpoint': 'True'}},
-                client_config=None),
-            {'use_dualstack_endpoint': True}
-        )
-        self.assertEqual(
-            self.args_create.compute_s3_config(
-                {'s3': {'use_dualstack_endpoint': 'true'}},
-                client_config=None),
-            {'use_dualstack_endpoint': True}
-        )
-        self.assertEqual(
-            self.args_create.compute_s3_config(
-                {'s3': {'use_dualstack_endpoint': True}},
-                client_config=None),
-            {'use_dualstack_endpoint': True}
-        )
-
     def test_max_pool_from_client_config_forwarded_to_endpoint_creator(self):
         config = botocore.config.Config(max_pool_connections=20)
         with mock.patch('botocore.args.EndpointCreator') as m:
@@ -228,12 +177,6 @@ class TestCreateClientArgs(unittest.TestCase):
             endpoint_url='http://other.com/')
         self.assertEqual(client_args['client_config'].region_name, None)
 
-    def test_provide_retry_config(self):
-        config = botocore.config.Config(retries={'max_attempts': 10})
-        client_args = self.call_get_client_args(client_config=config)
-        self.assertEqual(
-            client_args['client_config'].retries, {'max_attempts': 10})
-
     def test_tcp_keepalive_enabled(self):
         scoped_config = {'tcp_keepalive': 'true'}
         with mock.patch('botocore.args.EndpointCreator') as m:
@@ -357,3 +300,73 @@ class TestCreateClientArgs(unittest.TestCase):
                 service_model=self._get_service_model('sts'),
                 region_name='us-west-2', endpoint_url=None
             )
+
+    def test_provides_total_max_attempts(self):
+        config = botocore.config.Config(retries={'total_max_attempts': 10})
+        client_args = self.call_get_client_args(client_config=config)
+        self.assertEqual(
+            client_args['client_config'].retries['total_max_attempts'], 10)
+
+    def test_provides_total_max_attempts_has_precedence(self):
+        config = botocore.config.Config(retries={'total_max_attempts': 10,
+                                                 'max_attempts': 5})
+        client_args = self.call_get_client_args(client_config=config)
+        self.assertEqual(
+            client_args['client_config'].retries['total_max_attempts'], 10)
+        self.assertNotIn('max_attempts', client_args['client_config'].retries)
+
+    def test_provide_retry_config_maps_total_max_attempts(self):
+        config = botocore.config.Config(retries={'max_attempts': 10})
+        client_args = self.call_get_client_args(client_config=config)
+        self.assertEqual(
+            client_args['client_config'].retries['total_max_attempts'], 11)
+        self.assertNotIn('max_attempts', client_args['client_config'].retries)
+
+    def test_can_merge_max_attempts(self):
+        self.config_store.set_config_variable('max_attempts', 4)
+        config = self.call_get_client_args()['client_config']
+        self.assertEqual(config.retries['total_max_attempts'], 4)
+
+    def test_uses_config_value_if_present_for_max_attempts(self):
+        config = self.call_get_client_args(
+                client_config=Config(retries={'max_attempts': 2})
+        )['client_config']
+        self.assertEqual(config.retries['total_max_attempts'], 3)
+
+    def test_uses_client_config_over_config_store_max_attempts(self):
+        self.config_store.set_config_variable('max_attempts', 4)
+        config = self.call_get_client_args(
+                client_config=Config(retries={'max_attempts': 2})
+        )['client_config']
+        self.assertEqual(config.retries['total_max_attempts'], 3)
+
+    def test_uses_client_config_total_over_config_store_max_attempts(self):
+        self.config_store.set_config_variable('max_attempts', 4)
+        config = self.call_get_client_args(
+                client_config=Config(retries={'total_max_attempts': 2})
+        )['client_config']
+        self.assertEqual(config.retries['total_max_attempts'], 2)
+
+    def test_max_attempts_unset_if_retries_is_none(self):
+        config = self.call_get_client_args(
+                client_config=Config(retries=None)
+        )['client_config']
+        self.assertEqual(config.retries, {'mode': 'legacy'})
+
+    def test_retry_mode_set_on_config_store(self):
+        self.config_store.set_config_variable('retry_mode', 'standard')
+        config = self.call_get_client_args()['client_config']
+        self.assertEqual(config.retries['mode'], 'standard')
+
+    def test_retry_mode_set_on_client_config(self):
+        config = self.call_get_client_args(
+                client_config=Config(retries={'mode': 'standard'})
+        )['client_config']
+        self.assertEqual(config.retries['mode'], 'standard')
+
+    def test_client_config_beats_config_store(self):
+        self.config_store.set_config_variable('retry_mode', 'adaptive')
+        config = self.call_get_client_args(
+                client_config=Config(retries={'mode': 'standard'})
+        )['client_config']
+        self.assertEqual(config.retries['mode'], 'standard')
